<li class="nav-item">
    <a class="nav-link" href="/people/" title="People"><i class="fas fa-users"></i></a>
</li>
{% if active_page == 'people' %}
<li class="nav-item">
    <a class="nav-link" href="/people/add" title="People"><i class="fas fa-plus-circle"></i></a>
</li>
<li class="nav-item">
    <a class="nav-link" href="/people/lookup" title="Search"><i class="fas fa-search"></i></a>
</li>
{%endif%}