

<nav class="nav bg-light">
    <li class="nav-item">
      <a class="nav-link" href="{{url_for('admin.user_list')}}" title="Category home">
        <button type="button" class="btn btn-info">
            users
        </button>
      </a>
    </li>
    <li class="nav-item">
      <a class="nav-link" href="{{url_for('admin.user_add')}}" title="{{category}} List">
        <button type="button" class="btn btn-info">
            add user
        </button>
      </a>
    </li>
    <li class="nav-item">
      <a class="nav-link" href="{{url_for('admin.roles')}}" title="{{category}} List">
        <button type="button" class="btn btn-info">
            manage roles
        </button>
      </a>
    </li>
    
</nav>