{% extends "base/main_base.html" %}

{% set active_page ='' %}

{% block pagehead %}

{% endblock %}

{% block content %}

  <br>

    {% for info in all_info %}
    <div>
      name: {{all_info[info]['name']}}<br>
      type: {{all_info[info]['type']}}<br>
      url: <a style="color: rgb(100, 100, 100); font-style: underline;" href="{{all_info[info]['url_prefix']}}">{{all_info[info]['url_prefix']}}</a>
    </div>
    <hr>
        
    {% endfor %}
 {% endblock %}