<nav class="nav bg-light">
    <li class="nav-item">
      <a class="nav-link" href="/category/" title="Category home">
        <button type="button" class="btn btn-info">
            <i class="fa fa-store"></i>
        </button>
      </a>
    </li>
    <li class="nav-item">
      <a class="nav-link" href="/prods/list_prods/{{category}}" title="{{category}} List">
        <button type="button" class="btn btn-info">
            <i class="fa fa-shopping-bag"></i>
        </button>
      </a>
    </li>
    <li class="nav-item">
      <a class="nav-link" href="/prods/add/{{category}}" title="Add Product">
        <button type="button" class="btn btn-info">
            <i class="fas fa-plus-circle"></i>
        </button>
        
      </a>
    </li>
    <li class="nav-item">
      <a class="nav-link" href="/prods/lookup/{{category}}" title="Search">
        <button type="button" class="btn btn-info">
            <i class="fas fa-search"></i>
        </button>
      </a>
    </li>
</nav>